module Academical

  module Api

    # All schools that are using Academical
    class Schools

      def initialize(client)
        @client = client
      end

      # Returns a school object given its ID
      #
      # '/schools/:id' GET
      #
      # id - ID of the school
      def get(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/schools/#{id}", body, options)
      end

      # Delete a school from the API given its ID
      #
      # '/schools/:id' DELETE
      #
      # id - ID of the school
      def delete(id, options = {})
        body = options.fetch(:body, {})

        @client.delete("/schools/#{id}", body, options)
      end

      # Returns a list of schedules that have been created in a given school
      #
      # '/schools/:id/schedules' GET
      #
      # id - ID of the school
      def schedules(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/schools/#{id}/schedules", body, options)
      end

      # Returns a list of students for a given school
      #
      # '/schools/:id/students' GET
      #
      # id - ID of the school
      def students(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/schools/#{id}/students", body, options)
      end

      # Returns a list of sections for a given school
      #
      # '/schools/:id/sections' GET
      #
      # id - ID of the school
      def sections(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/schools/#{id}/sections", body, options)
      end

      # Return a list of teachers for a given school
      #
      # '/schools/:id/teachers' GET
      #
      # id - ID of the school
      def teachers(id, options = {})
        body = options.fetch(:query, {})

        @client.get("/schools/#{id}/teachers", body, options)
      end

      # Creates a new school object in Academical. All required parameters must be provided
      #
      # '/schools/' POST
      #
      # name - Name of the school
      # nickname - Nickname of the school
      # locale - Locale of the school
      # timezone - Timezone of the school
      # departments - A list of Department objects. Each department should specify a name and faculty_name
      # identity_providers - A list of Identify Providers to use with this school
      # app_ui - Object describing UI specific parameters for our planner app
      # terms - A list containing Term objects. Each term should define a name, a start date and end date.
      def create(name, nickname, locale, timezone, departments, identity_providers, app_ui, terms, options = {})
        body = options.fetch(:body, {})
        body[:name] = name
        body[:nickname] = nickname
        body[:locale] = locale
        body[:timezone] = timezone
        body[:departments] = departments
        body[:identity_providers] = identity_providers
        body[:app_ui] = app_ui
        body[:terms] = terms

        @client.post("/schools/", body, options)
      end

      # Update a new school in Academical. You must provide all of the required parameters
      #
      # '/schools/:id/' PUT
      #
      # id - Generated ID for the school
      # name - Name of the school
      # nickname - Nickname of the school
      # locale - Locale of the school
      # timezone - Timezone of the school
      # departments - A list of Department objects. Each department should specify a name and faculty_name
      # identity_providers - A list of Identify Providers to use with this school
      # app_ui - Object describing UI specific parameters for our planner app
      # terms - A list containing Term objects. Each term should define a name, a start date and end date.
      def update(id, name, nickname, locale, timezone, departments, identity_providers, app_ui, terms, options = {})
        body = options.fetch(:body, {})
        body[:name] = name
        body[:nickname] = nickname
        body[:locale] = locale
        body[:timezone] = timezone
        body[:departments] = departments
        body[:identity_providers] = identity_providers
        body[:app_ui] = app_ui
        body[:terms] = terms

        @client.put("/schools/#{id}/", body, options)
      end

    end

  end

end
